==> ejc-budgetmanage-impl-3.0.0-20220325.144208-24-sources.jar: com/ejianc/business/change/bean/ChangesubpackageEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_subpackage")
public class ChangesubpackageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="subcontract_unit")
    private java.lang.Long subcontractUnit; // 分包单位
    @TableField(value="subcontract_unit_name")
    private java.lang.String subcontractUnitName; // 分包单位名称
    @TableField(value="excluding_tax_total")
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    @TableField(value="including_tax_total")
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changesubpackagedetailService",pidName = "mid")
    private List<ChangesubpackagedetailEntity> subpackagedetailEntities = new ArrayList<>(); // 分包施工图预算变更子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
    /**
     * 分包施工图预算变更子表
     */
    public List<ChangesubpackagedetailEntity> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }

    /**
     * 分包施工图预算变更子表
     */
    public void setSubpackagedetailEntities(List<ChangesubpackagedetailEntity> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }


}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/change/bean/ChangesubpackageEntity.java <==
package com.ejianc.business.change.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_subpackage")
public class ChangesubpackageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="subcontract_unit")
    private java.lang.Long subcontractUnit; // 分包单位
    @TableField(value="subcontract_unit_name")
    private java.lang.String subcontractUnitName; // 分包单位名称
    @TableField(value="excluding_tax_total")
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    @TableField(value="including_tax_total")
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="excluding_tax_unit_price_total")
    private java.math.BigDecimal excludingTaxUnitPriceTotal; // 除税单价合计
    @TableField(value="including_tax_unit_price_total")
    private java.math.BigDecimal includingTaxUnitPriceTotal; // 含税单价合计
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changesubpackagedetailService",pidName = "mid")
    private List<ChangesubpackagedetailEntity> subpackagedetailEntities = new ArrayList<>(); // 分包施工图预算变更子表


    public BigDecimal getExcludingTaxUnitPriceTotal() {
        return excludingTaxUnitPriceTotal;
    }

    public void setExcludingTaxUnitPriceTotal(BigDecimal excludingTaxUnitPriceTotal) {
        this.excludingTaxUnitPriceTotal = excludingTaxUnitPriceTotal;
    }

    public BigDecimal getIncludingTaxUnitPriceTotal() {
        return includingTaxUnitPriceTotal;
    }

    public void setIncludingTaxUnitPriceTotal(BigDecimal includingTaxUnitPriceTotal) {
        this.includingTaxUnitPriceTotal = includingTaxUnitPriceTotal;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
    /**
     * 分包施工图预算变更子表
     */
    public List<ChangesubpackagedetailEntity> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }

    /**
     * 分包施工图预算变更子表
     */
    public void setSubpackagedetailEntities(List<ChangesubpackagedetailEntity> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }


}
